@@ -21,10 +21,6 @@ struct sip_sideal
   int nrows;
   int ncols;
   #define IDELEMS(i) ((i)->ncols)
-  #define MATCOLS(i) ((i)->ncols)
-  #define MATROWS(i) ((i)->nrows)
-  #define MATELEM(mat,i,j) ((mat)->m)[MATCOLS((mat)) * ((i)-1) + (j)-1]
-
 };
 /* the settings of rank, nrows, ncols, m ,   entries:
  * for IDEAL_CMD:     1    1    n    size n   poly              (n>=0)
@@ -59,6 +55,7 @@ EXTERN_VAR omBin sip_sideal_bin;
 
 /// creates an ideal / module
 ideal idInit (int size, int rank=1);
+#define id_Init(s,r,R) idInit(s,r)
 
 /*- deletes an ideal -*/
 void id_Delete (ideal* h, ring r);
@@ -68,6 +65,8 @@ void idSkipZeroes (ideal ide);
 
 /// number of non-zero polys in F
 int     idElem(const ideal F);
+#define id_Elem(F,R) idElem(F)
+
 /// normialize all polys in id
 void    id_Normalize(ideal id, const ring r);
 
@@ -75,11 +74,12 @@ int id_MinDegW(ideal M,intvec *w, const ring r);
 
 #ifdef PDEBUG
 void id_DBTest(ideal h1, int level, const char *f,const int l, const ring lR, const ring tR );
-#define id_TestTail(A, lR, tR) id_DBTest(A, PDEBUG, __FILE__,__LINE__, lR, tR)
+void id_DBLmTest(ideal h1, int level, const char *f,const int l, const ring r);
 #define id_Test(A, lR) id_DBTest(A, PDEBUG, __FILE__,__LINE__, lR, lR)
+#define id_LmTest(A, lR) id_DBLmTest(A, PDEBUG, __FILE__,__LINE__, lR)
 #else
-#define id_TestTail(A, lR, tR)  do {} while (0)
 #define id_Test(A, lR) do {} while (0)
+#define id_LmTest(A, lR) do {} while (0)
 #endif
 
 ideal id_Copy (ideal h1,const ring r);
@@ -109,6 +109,7 @@ void id_Norm(ideal id, const ring r);
 void id_DelEquals(ideal id, const ring r);
 void id_DelLmEquals(ideal id, const ring r);
 void id_DelDiv(ideal id, const ring r);
+void id_DelDiv_Sorted(ideal id, const ring r);
 BOOLEAN id_IsConstant(ideal id, const ring r);
 
 /// sorts the ideal w.r.t. the actual ringordering
@@ -122,6 +123,8 @@ void id_Compactify(ideal id, const ring r);
 ideal  id_Mult (ideal h1,ideal  h2, const ring r);
 ideal id_Homogen(ideal h, int varnum,const ring r);
 BOOLEAN id_HomIdeal (ideal id, ideal Q, const ring r);
+BOOLEAN id_HomIdealW (ideal id, ideal Q,  const intvec *w, const ring r);
+BOOLEAN id_HomModuleW (ideal id, ideal Q,  const intvec *w, const intvec *module_w, const ring r);
 BOOLEAN id_HomModule(ideal m, ideal Q, intvec **w, const ring R);
 BOOLEAN id_IsZeroDim(ideal I, const ring r);
 ideal id_Jet(const ideal i,int d, const ring R);
